@@ -34,9 +34,6 @@ class DeleteColumnsCodeChunk(CodeChunk):
 
         return [f'{df_name}.drop({column_headers_list_string}, axis=1, inplace=True)']
 
-    def get_edited_sheet_indexes(self) -> List[int]:
-        return [self.get_param('sheet_index')]
-
     def _combine_right_with_delete_columns_code_chunk(self, other_code_chunk: "DeleteColumnsCodeChunk") -> Optional["DeleteColumnsCodeChunk"]:
         if not self.params_match(other_code_chunk, ['sheet_index']):
             return None
